#include <iostream>
#include <iomanip>
#include <vector>
#include <queue>
#include <algorithm>
#include <utility>
#include <cmath>

using namespace std;

typedef double coord;

class point {
public:
        coord x, y;

        point() { x = y = 0; }
        point(coord x1, coord y1) { x = x1; y = y1; }

        point operator +=(point a) { x += a.x; y += a.y; return *this; }
        point operator -=(point a) { x -= a.x; y -= a.y; return *this; }
};

point operator +(point a, point b) { return a += b; }
point operator -(point a, point b) { return a -= b; }
coord operator *(point a, point b) { return a.x*b.x + a.y*b.y; }

coord cross(point a, point b) { return a.x*b.y - a.y*b.x; }
double length(point a) { return sqrt((double)(a*a)); }

int main()
{
	int n;
	cin >> n;

	cout << setprecision(15);

	double triangle = sqrt(0.75)/2;

	if ( n==2 ) {
		cout << triangle << endl;
		return 0;
	}

	vector<point> poly(n);
	for(int i=0; i<n; i++) cin >> poly[i].x >> poly[i].y;

	double area = 0, scale = 0;
	for(int i=0; i<n-1; i++) {
		area += cross(poly[i+1], poly[i]) / 2;
		point d = poly[i+1] - poly[i];
		scale += d*d;
	}

	double fac = 1 / (1 - scale);

	double res = triangle + 3 * fac * area;

	fprintf(stderr, "triangle = %.3lf\nscale = %.3lf => fac = %.3lf\narea = %.3lf\n",
	        triangle, scale, fac, area);

	cout << res << endl;

	return 0;
}
