import java.io.*;
import java.util.*;

public class MaartenScannerIntOverflow {
    public static void main(String[] args) throws IOException {
        try (BufferedReader reader = new BufferedReader(new InputStreamReader(System.in))) {
            new MaartenScannerIntOverflow().run(new Scanner(reader));
        }
    }

    public void run(Scanner sc) throws IOException {
        int n = sc.nextInt();
        int[] buyTree = new int[2 * n];
        int[] sellTree = new int[2 * n];
        PriorityQueue<int[]> buys = new PriorityQueue<>(Comparator.<int[]>comparingInt(a -> a[0]).thenComparingInt(a -> a[1]).thenComparingInt(a -> a[2]));
        PriorityQueue<int[]> sells = new PriorityQueue<>(Comparator.<int[]>comparingInt(a -> a[0]).thenComparingInt(a -> a[1]).thenComparingInt(a -> a[2]));
        List<int[]> orders = new ArrayList<>();

        for (int i = 0; i < n; i++) {
            boolean buy = sc.next().equals("buy");
            boolean fok = sc.next().equals("fok");
            int price = sc.nextInt();
            int amount = sc.nextInt();
            orders.add(new int[]{buy ? 1 : 0, fok ? 1 : 0, price, amount});
        }

        Map<Integer, Integer> buyIndex = new HashMap<>();
        Map<Integer, Integer> sellIndex = new HashMap<>();

        List<int[]> sortedPrices = new ArrayList<>();
        for (int i = 0; i < orders.size(); i++) {
            sortedPrices.add(new int[]{i, orders.get(i)[2]});
        }
        sortedPrices.sort(Comparator.<int[]>comparingInt(a -> a[1]).thenComparingInt(a -> -a[0]));
        for (int i = 0; i < sortedPrices.size(); i++) {
            buyIndex.put(sortedPrices.get(i)[0], i);
        }
        sortedPrices.sort(Comparator.<int[]>comparingInt(a -> a[1]).thenComparingInt(a -> a[0]));
        for (int i = 0; i < sortedPrices.size(); i++) {
            sellIndex.put(sortedPrices.get(i)[0], i);
        }

        List<int[]> answers = new ArrayList<>();
        for (int i = 0; i < orders.size(); i++) {
            int[] order = orders.get(i);
            boolean buy = order[0] == 1;
            boolean fok = order[1] == 1;
            int p = order[2];
            int a = order[3];

            if (buy) {
                int remaining = SumSegTree.range_query(sellTree, 0, sellIndex.get(i));
                if (!fok || remaining >= a) {
                    while (remaining > 0 && !sells.isEmpty() && a > 0) {
                        int[] sellOrder = sells.poll();
                        int sellP = sellOrder[0];
                        int sellI = sellOrder[1];
                        int sellA = sellOrder[2];
                        int amount = Math.min(a, Math.min(sellA, remaining));
                        SumSegTree.update(sellTree, sellIndex.get(sellI), sellA - amount);
                        if (sellA - amount > 0) {
                            sells.offer(new int[]{sellP, sellI, sellA - amount});
                        }
                        remaining -= amount;
                        a -= amount;
                        answers.add(new int[]{i + 1, sellI + 1, amount});
                    }
                    if (a > 0) {
                        SumSegTree.update(buyTree, buyIndex.get(i), a);
                        buys.offer(new int[]{-p, i, a}); // Highest price first, so negate price
                    }
                }
            } else {
                int remaining = SumSegTree.range_query(buyTree, buyIndex.get(i), n);
                if (!fok || remaining >= a) {
                    while (remaining > 0 && !buys.isEmpty() && a > 0) {
                        int[] buyOrder = buys.poll();
                        int buyP = buyOrder[0];
                        int buyI = buyOrder[1];
                        int buyA = buyOrder[2];
                        int amount = Math.min(a, Math.min(buyA, remaining));
                        SumSegTree.update(buyTree, buyIndex.get(buyI), buyA - amount);
                        if (buyA - amount > 0) {
                            buys.offer(new int[]{buyP, buyI, buyA - amount});
                        }
                        remaining -= amount;
                        a -= amount;
                        answers.add(new int[]{buyI + 1, i + 1, amount});
                    }
                    if (a > 0) {
                        SumSegTree.update(sellTree, sellIndex.get(i), a);
                        sells.offer(new int[]{p, i, a}); // Lowest price first
                    }
                }
            }
        }

        System.out.println(answers.size());
        for (int[] answer : answers) {
            System.out.println(answer[1] + " " + answer[0] + " " + answer[2]);
        }
    }

    // Java Program to implement iterative segment tree.
    // Source: https://www.geeksforgeeks.org/iterative-segment-tree-range-minimum-query/
    // Adapted to use Sum instead of Min
    static class SumSegTree {

        static void update(int[] segtree, int pos, int value) {

            // change the index to leaf node first
            pos += segtree.length / 2;

            // update the value at the leaf node
            // at the exact index
            segtree[pos] = value;

            while (pos > 1) {

                // move up one level at a time in the tree
                pos >>= 1;

                // update the values in the nodes in
                // the next higher level
                segtree[pos] = segtree[2 * pos] + segtree[2 * pos + 1];
            }
        }

        static int range_query(int[] segtree, int left, int right) {

            /*
             * Basically the left and right indices will move
             * towards right and left respectively and with
             * every each next higher level and compute the
             * minimum at each height. */
            // change the index to leaf node first
            left += segtree.length / 2;
            right += segtree.length / 2;

            int ans = 0;

            while (left < right) {

                // if left index is odd
                if ((left & 1) == 1) {
                    ans += segtree[left];

                    // make left index even
                    left++;
                }

                // if right index is odd
                if ((right & 1) == 1) {

                    // make right index even
                    right--;

                    ans += segtree[right];
                }

                // move to the next higher level
                left >>= 1;
                right >>= 1;
            }
            return ans;
        }

    }

}
